/* Pong - A version of Pong based on Ncurses
 * Copyright (C) 1999 Jeffrey Wade Starr <starr81@ix.netcom.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */   

// event.h
// Event Manager for Pong
// By Jeffrey W. Starr Oct 14 1998

#ifndef EVENT_H
#define EVENT_H

#include <limits.h>
#include "controls.h"

int timetick = 5;

class Event
{
 public:
  Event();           // constructor
  bool ok();
  void incrScore();       // increase score
  int getScore();    // return the current score
 private:
  int score;
};

Event::Event()
{
  score = 0;
}

inline void Event::incrScore()
{
  score++;
}

inline int Event::getScore()
{
  return score;
}

bool ok(Random * rnd, Ball * ball, Paddle * paddle, Event * event);

inline bool slower()
{
  if(timetick + 1 < 10)
    timetick += 1;
  else
    return false;
  return true;
}

inline bool faster()
{
  if(timetick - 1 > 10)
    timetick -= 1;
  else
    return false;
  return true;
}

bool ok(Random * rnd, Ball * ball, Paddle * paddle, Event * event)
{
  const int LEFT   =  0;
  const int RIGHT  = 79;
  const int TOP    =  0;
  const int BOTTOM = 23;

  static int tick = 1;

  int bypos = ball->distTop();
  int bxpos = ball->distEdge();
  int bdir  = ball->direction();

  int pxpos = paddle->getXc();

  // first test if the game has been lost
  if( timetick % tick == 2)
    {
      if(bypos == BOTTOM - 2)
	{
	  if((pxpos == bxpos) || (pxpos == bxpos + 1) || (pxpos == bxpos - 1))
	    {
	      ball->bounce( rnd->next(3) + 7 );
	      event->incrScore();
	      if((timetick % tick == 2) && SOUND)
		system( "play ding.wav" );
	    }
	  else
	    {
	      ball->moveball();
	      return false;
	    }
	}
      // put a end to the if here if it doesn't work

  // test if it's about to hit the top of the screen
  if(bypos == TOP && (bdir == 7 || bdir == 8 || bdir == 9))
    ball->bounce( rnd->next(3) + 1 );

  // hit the right edge
  if(bxpos == RIGHT && (bdir == 9 || bdir == 6 || bdir == 3))
    {
      int go = rnd->next(2) + 1;
      switch(go)
	{
	case 0:  ball->bounce( 1 );  // shouldn't have to be included, but does
	  break;
	case 1:  ball->bounce( 1 ); break;
	case 2:  ball->bounce( 7 ); break;
	}
    }

  // hit the left edge
  if(bxpos == LEFT && (bdir == 1 || bdir == 4 || bdir == 7))
    {
      int go = rnd->next(2) + 1;
      switch( go )
	{
	case 0:  ball->bounce( 3 );  // shouldn't have to be included, but does
	  break;
	case 1:  ball->bounce( 9 ); break;
	case 2:  ball->bounce( 3 ); break;
	}
    }

    }
  // so, it hasn't hit any of the edges

  if( (timetick % tick) == 2 )
    ball->moveball();
  
  tick ++ ;

  if(tick > timetick)
    tick = 1;

  return true;
}

#endif












